@@ -157,6 +157,7 @@ class create_all:
 		self.window=self.tree.get_widget("wprogress")
 		self.partial=self.tree.get_widget("progresspartial")
 		self.erase_temp=global_vars["erase_temporary_files"]
+		self.iso_creator=global_vars["iso_creator"]
 
 		self.queue=[]
 		self.current_action=0
@@ -415,7 +416,7 @@ class create_all:
 			return True
 
 		if action[0]=="DVD_IMAGE":
-			self.runner=devede_bincue.iso_generator(self.filename,self.filefolder,self.partial,self.label)
+			self.runner=devede_bincue.iso_generator(self.filename,self.filefolder,self.partial,self.label,self.iso_creator)
 			return True
 		
 		if action[0]=="END":
