@@ -32,7 +32,8 @@ class delete_files:
 		
 		self.filename=filename
 		self.filefolder=filefolder
-		self.filepath=filefolder+filename
+		self.filepath=os.path.join(filefolder,filename)
+		print "Path para borrar: "+str(self.filepath)
 
 
 	def delete_all(self):
@@ -46,6 +47,7 @@ class delete_files:
 		self.delete_mpg()
 		self.delete_sub_xml()
 		self.delete_xml()
+		self.delete_main_dir()
 
 
 	def delete_mpg(self):
@@ -80,54 +82,83 @@ class delete_files:
 		
 		try:
 			os.remove(self.filepath+".xml")
+			listfiles=glob.glob(self.filepath+"_menu_[0-9]"+".xml")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
 			print self.filepath+".xml not found"
 
 
 	def delete_menu_temp(self):
 	
+		print "delete menu temp"
 		try:
-			os.remove(self.filepath+"_menu.xml")
+			listfiles=glob.glob(self.filepath+"_menu[0-9]"+"_bg.png")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu.xml not found"
+			print "Can't delete "+self.filepath+"_menu?_bg.png"
+
 		try:
-			os.remove(self.filepath+"_menu.mpg")
+			listfiles=glob.glob(self.filepath+"_menu[0-9]"+"_bg_active_out.png")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu.mpg not found"
+			print "Can't delete "+self.filepath+"_menu?_bg_active_out.png"
+
 		try:
-			os.remove(self.filepath+"_menu_bg.png")
+			listfiles=glob.glob(self.filepath+"_menu[0-9]"+"_bg_inactive_out.png")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu_bg.png not found"
+			print "Can't delete "+self.filepath+"_menu?_bg_inactive_out.png"
+			
 		try:
-			os.remove(self.filepath+"_menu_bg_active.png")
+			listfiles=glob.glob(self.filepath+"_menu[0-9]"+"_bg_select_out.png")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu_bg_active.png not found"
+			print "Can't delete "+self.filepath+"_menu?_bg_select_out.png"
+
 		try:
-			os.remove(self.filepath+"_menu_bg_active_out.png")
+			listfiles=glob.glob(self.filepath+"_menu_[0-9]"+".mpg")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu_bg_active_out.png not found"
-		try:
-			os.remove(self.filepath+"_menu_bg_inactive.png")
-		except OSError:
-			print self.filepath+"_menu_bg_inactive.png not found"
-		try:
-			os.remove(self.filepath+"_menu_bg_inactive_out.png")
-		except OSError:
-			print self.filepath+"_menu_bg_inactive_out.png not found"
-		try:
-			os.remove(self.filepath+"_menu_bg_select.png")
-		except OSError:
-			print self.filepath+"_menu_bg_select.png not found"
-		try:
-			os.remove(self.filepath+"_menu_bg_select_out.png")
-		except OSError:
-			print self.filepath+"_menu_bg_select_out.png not found"
+			print "Can't delete "+self.filepath+"_menu_?.mpg"
+
 
 	def delete_menu(self):
+		
+		print "delete menu"
+		
 		try:
-			os.remove(self.filepath+"_menu2.mpg")
+			listfiles=glob.glob(self.filepath+"_menu2_[0-9]"+".mpg")
+			for afile in listfiles:
+				try:
+					os.remove(afile)
+				except OSError:
+					print str(afile.strip())+" not found to remove"
 		except OSError:
-			print self.filepath+"_menu2.mpg not found"
+			print "Can't delete "+self.filepath+"_menu2_?.mpg"
 
 
 	def delete_sub_xml(self):
@@ -165,3 +196,13 @@ class delete_files:
 			shutil.rmtree(self.filepath)
 		except OSError:
 			print self.filepath+os.sep+" not found"
+			
+	def delete_main_dir(self):
+
+		print "Borro principal"
+		return
+
+		try:
+			shutil.rmtree(self.filepath)
+		except OSError:
+			print self.filepath+os.sep+" not found"
