@@ -43,6 +43,7 @@ class video_converter(devede_executor.executor):
 		PROGLABEL is the label where the class will show what is it doing
 		DISCTYPE can be dvd, vcd, svcd, cvd or divx
 		TITLE and CHAPTER are the numbers used to identify the TITLE and CHAPTER number for this file
+		THREADS is the number of threads to use
 		SECONDS is the number of seconds we want to convert (for previews) """
 		
 		devede_executor.executor.__init__(self,filename,filefolder,progresbar)
@@ -95,6 +96,7 @@ class video_converter(devede_executor.executor):
 
 		addbars=False
 		framerate=int(videofile["ofps"])
+
 		videorate=int(videofile["vrate"])
 		audiorate=int(videofile["arate"])
 		audio_final_rate=int(videofile["arateunc"])
@@ -110,6 +112,12 @@ class video_converter(devede_executor.executor):
 		sound51=videofile["sound51"]
 		gop12=videofile["gop12"]
 		audiostream=videofile["audio_stream"]
+		
+		speed1,speed2=devede_other.get_speedup(videofile)
+		if speed1==speed2:
+			speedup=None
+		else:
+			speedup=str(speed1)+":"+str(speed2)
 	
 		if aspect_ratio_original<1.3:
 			aspect_ratio_original=float(videofile["owidth"])/(float(videofile["oheight"]))
@@ -171,12 +179,18 @@ class video_converter(devede_executor.executor):
 		else:
 			audio_desired_final_rate=44100
 
-		if (audio_final_rate!=audio_desired_final_rate) and (copy_audio==False):
+		if ((audio_final_rate!=audio_desired_final_rate) and (copy_audio==False)) or (speedup!=None):
 			command_var.append("-srate")
 			command_var.append(str(audio_desired_final_rate))
 			command_var.append("-af")
 			command_var.append("lavcresample="+str(audio_desired_final_rate))
 
+		# Add the speedup code
+
+		if speedup!=None:
+			command_var.append("-speed")
+			command_var.append(speedup)
+
 		command_var.append("-oac")
 		if copy_audio:
 			command_var.append("copy")
@@ -273,7 +287,10 @@ class video_converter(devede_executor.executor):
 		if videofile["deinterlace"]!="none":
 			if acoma:
 				lineatemp+=","
-			lineatemp+="pp="+videofile["deinterlace"]
+			if videofile["deinterlace"]!="yadif":
+				lineatemp+="pp="+videofile["deinterlace"]
+			else:
+				lineatemp+="yadif=0"
 			acoma=True
 			
 		if videofile["rotate"]==180:
